# Confu

[![PyPI](https://img.shields.io/pypi/v/cfu.svg?maxAge=60)](https://pypi.python.org/pypi/cfu)
[![PyPI](https://img.shields.io/pypi/pyversions/cfu.svg?maxAge=600)](https://pypi.python.org/pypi/cfu)
[![Travis CI](https://img.shields.io/travis/20c/confu.svg?maxAge=60)](https://travis-ci.org/20c/confu)
[![Codecov](https://img.shields.io/codecov/c/github/20c/confu/master.svg?maxAge=60)](https://codecov.io/github/20c/confu)
[![Requires.io](https://img.shields.io/requires/github/20c/confu.svg?maxAge=60)](https://requires.io/github/20c/confu/requirements)

Configuration validation and generation

# Supports

  - python 2.7
  - python 3.4
  - python 3.5
  - python 3.6

# Documentation 

  - **stable**: https://confu.readthedocs.io/en/stable/quickstart/
  - **latest**: https://confu.readthedocs.io/en/latest/quickstart/

